class TextTheme<TextSize> {
  final TextSize size;
  final bool isBold;
  final bool isItalic;

  const TextTheme({
    required this.size,
    required this.isBold,
    this.isItalic = false,
  });
}

abstract class CoreTheme<TextSize> {
  final TextTheme<TextSize> h1;
  final TextTheme<TextSize> h2;
  final TextTheme<TextSize> h3;
  final TextTheme<TextSize> subTitle1;
  final TextTheme<TextSize> subTitle2;
  final TextTheme<TextSize> body1;
  final TextTheme<TextSize> body2;
  final TextTheme<TextSize> caption;

  const CoreTheme({
    required this.h1,
    required this.h2,
    required this.h3,
    required this.subTitle1,
    required this.subTitle2,
    required this.caption,
    required this.body1,
    required this.body2,
  });
}

class DefaultTheme extends CoreTheme<int> {
  const DefaultTheme()
      : super(
          h1: const TextTheme<int>(
            size: 30,
            isBold: true,
          ),
          h2: const TextTheme<int>(
            size: 26,
            isBold: false,
          ),
          h3: const TextTheme<int>(
            size: 24,
            isBold: true,
          ),
          subTitle1: const TextTheme<int>(
            size: 22,
            isBold: true,
          ),
          subTitle2: const TextTheme<int>(
            size: 22,
            isBold: false,
          ),
          body1: const TextTheme<int>(
            size: 20,
            isBold: false,
          ),
          body2: const TextTheme<int>(
            size: 18,
            isBold: false,
          ),
          caption: const TextTheme<int>(
            size: 16,
            isBold: false,
          ),
        );
}
